@@ -509,7 +509,7 @@ class Query:
     def _simple_query(self, sql):
         sql = self._prep_query(sql)
         query_result = False
-        if not Connection._show_error:
+        if not Connection.show_error:
             try:
                 query_result = self._db.execute(sql)
                 self._error = None
@@ -595,13 +595,13 @@ class Query:
             self.set(data)
 
         if len(self._ar_set) == 0:
-            if Connection._show_error:
+            if Connection.show_error:
                 raise HTTPError(500, 'Use Query.set to sql write data')
             return False
 
         if not table:
             if len(self._ar_from) == 0:
-                if Connection._show_error:
+                if Connection.show_error:
                     raise HTTPError(500, 'Must set table name')
                 return False
             table = self._ar_from[0]
@@ -630,13 +630,13 @@ class Query:
             self.set(data)
 
         if len(self._ar_set) == 0:
-            if Connection._show_error:
+            if Connection.show_error:
                 raise HTTPError(500, 'Use Query.set to sql write data')
             return False
 
         if not table:
             if len(self._ar_from) == 0:
-                if Connection._show_error:
+                if Connection.show_error:
                     raise HTTPError(500, 'Must set table name')
                 return False
             table = self._ar_from[0]
@@ -679,7 +679,7 @@ class Query:
     def delete(self, table='', where='', limit=None, reset_data=True):
         if not table:
             if len(self._ar_from) == 0:
-                if Connection._show_error:
+                if Connection.show_error:
                     raise HTTPError(500, 'Must set table name')
                 return False
             table = self._ar_from[0]
@@ -697,7 +697,7 @@ class Query:
             self.limit(limit)
 
         if len(self._ar_where) == 0 and len(self._ar_wherein) == 0 and len(self._ar_like) == 0:
-            if Connection._show_error:
+            if Connection.show_error:
                 raise HTTPError(500, 'Delete must use where')
             return False
 
@@ -707,7 +707,7 @@ class Query:
     def empty_table(self, table=''):
         if not table:
             if len(self._ar_from) == 0:
-                if Connection._show_error:
+                if Connection.show_error:
                     raise HTTPError(500, 'Must set table name')
                 return False
             table = self._ar_from[0]
@@ -723,7 +723,7 @@ class Query:
     def truncate(self, table=''):
         if not table:
             if len(self._ar_from) == 0:
-                if Connection._show_error:
+                if Connection.show_error:
                     raise HTTPError(500, 'Must set table name')
                 return False
             table = self._ar_from[0]
@@ -735,18 +735,18 @@ class Query:
 
 class Connection:
 
-    _show_error = True
-    _engine = None
+    show_error = True
+    engine = None
 
     @staticmethod
     def set_engine(settings):
         if not settings:
             raise HTTPError(500, 'Database configuration is required')
-        Connection._engine = create_engine(
+        Connection.engine = create_engine(
             'mysql+pymysql://' + settings['user'] + 
             ':' + settings['passwd'] + '@' +
             settings['host'] + '/' + settings['db'],
-            echo=Connection._show_error,
+            echo=Connection.show_error,
             execution_options={
                 'no_parameters' : True
             }
@@ -755,13 +755,13 @@ class Connection:
     @staticmethod
     def create():
         try:
-            return Connection._engine.connect()
+            return Connection.engine.connect()
         except Exception as e:
             raise HTTPError(500, 'Unable to connect to your database server using the provided settings.')
 
     @staticmethod
     def set_debug(val=True):
-        Connection._show_error = val
+        Connection.show_error = val
 
 class Model:
     def __init__(self, db):
